function W = comp_W(data, Ae, Sigmae )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Computes Wald statistics 
%Input:
% data      = measurements (N X K)
% Ae        = est. coeff. flat matrix (K X (K*p))
% Sigmae    = est. cov. marix driven noise
%Output:
% W         = W matrix (K X K)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[N, K] = size(data);
[~, temp] = size(Ae);
p = temp/K;

invAvar = zeros(K^2*p,K^2*p);
for t=p+1:N,
    bary = vec( data(t-1:-1:t-p,:) );
    Hbar = kron(eye(K,K),bary');
    invAvar = invAvar + (Hbar'/Sigmae)*Hbar;        
end
Avar = inv(invAvar);

W = Inf*ones(K);
for i=1:K
    for j=1:K
        posj = (0:(p-1))*K + j;
        r = Ae(i,posj)';
        pos_start = (i-1)*K*p +(j-1)*p +1;
        pos_stop = pos_start + p -1;
        W(i,j) = r'*(Avar(pos_start:pos_stop,pos_start:pos_stop)\r);
    end
end

end %function

