function [vec_crit, logdetSigma] = eval_crit(data, n, phat, A, noz)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Computes values of four ITC
%Input:
% data          = measurements
% n             = no. of components of time series
% phat          = estimated VAR order
% A             = est. coeff. fat matrix (n X (n*phat))
% noz           = number of zeros in the mask 
%Output:
% vec_crit      = values ITC: (1) SBC; (2) FPE; (3) RNML; (4) AICC; 
%                             (5) EBIC; (6) ERNML 
% logdetSigma   = log det est. cov. matrix errors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

B = [eye(n) -A];

%Compute log(det(Sigma))
N = size(data, 1);
T = N - phat;
Ut= zeros(T, n*(phat+1));
for j = 1:phat+1
    Ut(:,n*(j-1)+1:j*n) = data(phat+2-j:N-j+1,:);
end
temp  = Ut*B';
Sigma = temp'*temp/T;
logdetSigma = log(det(Sigma));

%Compute R2 (modified R)
Y = data(phat+1:end,:);
R2= trace(Y'*Y - T*Sigma)/T;

%No. of param. 
nop = (n^2 -noz)*phat;
nop1= nop/n;
 
vec_crit = Inf*ones(6,1);
%Here we calculate the values of the criteria

%SBC
vec_crit(1) = T*logdetSigma + nop*log(T);
   
%FPE    
vec_crit(2) = n*log((T+nop1)/(T-nop1))+logdetSigma;  

%RNML    
if R2 <= 0
        vec_crit(3) = Inf;
else
        ell     = nop1;
        term    = zeros(4,1);
        term(1) = ((T-ell-n+1)/2)*logdetSigma;
        term(2) = -sum(gammaln((T-ell:-1:T-ell+1-n)/2));
        term(3) = -gammaln(ell*n/2);
        term(4) = ((ell*n)/2)*log(R2);
        vec_crit(3) = sum(term);
end

%AICC    
vec_crit(4) = T*logdetSigma + (2*nop*T)/(T-nop-1);

%EBIC
vec_crit(5) =  vec_crit(1) + 4*nop*log(n);

%ERNML
vec_crit(6) = vec_crit(3) + 2*nop*log(n);

end %function


