function [Atrue, mask, spec_rad, ell] = gen_coeff_ell(K, p, c, z, lam_max )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generates the coeff. of the model 
%Input:
% K         = number of variables
% p         = order of the model
% c         = std of matrix coefficients
% z         = max probability of zeros
% lam_max   = upper bound spec. rad.
%Output:
% Atrue     = coeff. of the model
% mask      = pattern of zeros
% spec_rad  = spectral radius
% ell       = multiplication factor
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

spec_rad = Inf;
while (spec_rad>lam_max) || (spec_rad<(lam_max-lam_max/1000))

mineig  = 0;
while mineig<10^(-4)
    mask    = rand(K) > 1 - z;
    for i=1:K, mask(i,i)=0; end  % diagonal elements are nonzero
    M       = c * randn(K) .* (1 - mask);
    d1      = eig(M);
    mineig  = min(abs(d1));
end

ell = Inf;
for ind=1:K,
    mu = 1/d1(ind);
    q = roots([1 zeros(1,p-1) -(mu+1) mu]);
    ell = min(ell,min(abs(lam_max*q)));
end

for i = 1:p
        Atrue{i} = (ell^i)*M;
end

spec_rad = comp_spec_rad(Atrue);
% fprintf('%20.19f\n', spec_rad);

end %while

end %function


 