function [est_dist, est_coeff, est_spec_rad] = oracle(data, phat, masktrue, vec_diff, NoITC, tr, indN, indp, nit, tol_pos, val_coeff, est_dist, est_coeff, est_spec_rad, val_spec_rad)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Estimation by oracle
%Input:
% data          = measurements (N X K)
% phat          = est. order
% masktrue      = true mask (xor)
% vec_diff      = dist. from each candidate to the masktrue1    [1 X no. of candidates]
% NoITC         = total no. of ITC
% tr            = trial
% indN          = index sample size
% indp          = index phat in vec_phat
% nit           = no. of iterations
% tol_pos       = improves numerical conditioning
% val_coeff     = estimated coeff.(cell)                        [no. of candidates X no. of opt. methods+1]
% est_dist      = dist. from the est. mask to the true mask     [NoITCord+1 X NoITC+1 X Ntr X no. opt. met.+1 X no. sample sizes]
% est_coeff     = est. coeff.                              cell [NoITCord+1 X NoITC+1 X Ntr X no. opt. met.+1 X no. sample sizes]
% est_spec_rad  = est. spec. rad.                               [NoITCord+1 X NoITC+1 X Ntr X no. opt. met.+1 X no. sample sizes]
%Output:
% est_dist      = dist. from the est. mask to the true mask     [NoITCord+1 X NoITC+1 X Ntr X no. opt. met.+1 X no. sample sizes]
% est_coeff     = est. coeff.                              cell [NoITCord+1 X NoITC+1 X Ntr X no. opt. met.+1 X no. sample sizes]
% est_spec_rad  = est. spec. rad.                               [NoITCord+1 X NoITC+1 X Ntr X no. opt. met.+1 X no. sample sizes]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[min_vec_diff,w]                 = min(vec_diff);
est_dist(indp,NoITC+1,tr,:,indN) = vec_diff(w);

if min_vec_diff==0
    est_coeff(indp,NoITC+1,tr,:,indN)        = val_coeff(w,:); %modified Aug. 21, 2018
    est_spec_rad(indp,NoITC+1,tr,:,indN)     = val_spec_rad(w,:);
else
    met = 1;
    [Afls, ~] = granger_simple(data', phat, masktrue);
    est_coeff{indp,NoITC+1,tr,met,indN} = Afls;
    est_spec_rad(indp,NoITC+1,tr,met,indN) = comp_spec_rad(Afls);
    met = 2;
    [Afsong, ~] = granger_songsiri(data', phat, masktrue);
    est_coeff{indp,NoITC+1,tr,met,indN} = Afsong;
    est_spec_rad(indp,NoITC+1,tr,met,indN) = comp_spec_rad(Afsong);
    met = 3;
    [Af, ~] = run_granger_stab(data', phat, masktrue, nit, tol_pos, Afsong);
    est_coeff{indp,NoITC+1,tr,met,indN} = Af;
    est_spec_rad(indp,NoITC+1,tr,met,indN) = comp_spec_rad(Af);
end

end %function

