function [pred_err, max_pred_err] = pred(data, indN, tr, phat, indp, est_coeff, pred_err, max_pred_err, NoITC)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Computes prediction errors
%Input:
% data          = measurements (for prediction)
% indN          = index sample size used in training
% tr            = trial
% phat          = estimated VAR order
% indp          = index phat in vec_phat
% est_coeff     = est. coeff. cell      [NoITCord+1 X NoITC+1 X Ntr X 3 MET X no. sample sizes]
% pred_err      = pred. errors          [NoITCord+1 X NoITC+1 X Ntr X 3 MET X no. sample sizes]
% max_pred_err  = max. pred. errors     [NoITCord+1 X NoITC+1 X Ntr X 3 MET X no. sample sizes]
% NoITC         = total no. of ITC
%Output:
% pred_err      = pred. errors          [NoITCord+1 X NoITC+1 X Ntr X 3 MET X no. sample sizes]
% max_pred_err  = max. pred. errors     [NoITCord+1 X NoITC+1 X Ntr X 3 MET X no. sample sizes]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[N,n] = size(data);
T = N - phat;

for met=1:3
    for ind_crit=1:(NoITC+1)
           
        A = est_coeff{indp, ind_crit, tr, met, indN};
        
        if numel(A{1})>0  %modified August 21, 2018
            Yhat = zeros(n,N);
            Yhat(:,1:phat) = data(1:phat,:)';  
            for i = phat+1 : N
                x = zeros(n,1);
                for j = 1 : phat
                    x = x + A{j} * Yhat(:,i-j);
                end
                Yhat(:,i) = x;
            end
            err = data-Yhat';
        
            pred_err(indp, ind_crit, tr, met, indN) = sum(sum(err.^2))/T/n;
            max_pred_err(indp, ind_crit, tr, met, indN) = max(max(abs(err)));
        
        else
            fprintf('\n ERROR est. coeff: indp=%i ind_crit=%i tr=%i met=%i indN=%i \n', indp, ind_crit, tr, met, indN);
            pred_err(indp, ind_crit, tr, met, indN) = Inf;
            max_pred_err(indp, ind_crit, tr, met, indN) = Inf;
            
        end %if
                
    end
end

end %function

