function run_exp

%Initialization
Ntr                       = 1;                                %no. of trials
vec_N                     = (200:100:500);                    %sample sizes
Nmax                      = max(vec_N);                       %max. sample size
% p                         = 3;                                %order AR model
 p                         = 10;                                %order AR model
% K                         = 10;                               %no. of time series
 K                         = 3;                               %no. of time series
npow                      = 0.5;                              %cov. driven noise npow*eye(K)
c                         = 0.25;                             %std of matrix coefficients
z                         = 0.6;                              %max probability of zeros
flag_est_p                = 1;                                %1(estimate order), 0 (use the true order)
flag_gen_coeff            = 0;                                %1(gen_coeff_ell),  0 (gen_coeff)
lam_max                   = 0.99;                             %upper bound spec. rad. used by gen_coeff_ell 
nit                       = 10;                               %no. of iterations for run_granger_stab
tol_pos                   = 0.1;                              %improves numerical conditioning for run_granger_stab
NoITC                     = 6;                                %total number of ITC that are applied for selectiing the mask
h                         = 100;                              %h-step-ahead prediction
pmin                      = 1;                                %min. value for the estimated order
% pmax                      = 5;                                %max. value for the estimated order
pmax                      = 15;                                %max. value for the estimated order
NoITCord                  = 4;                                %total number of ITC that are applied for selectiing the order

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

est_dist            = Inf*ones(NoITCord+1,NoITC+1,Ntr,3,length(vec_N));
est_spec_rad        = Inf*ones(NoITCord+1,NoITC+1,Ntr,3,length(vec_N));
est_coeff           = cell(NoITCord+1,NoITC+1,Ntr,3,length(vec_N));
vec_spec_rad_sys    = Inf*ones(Ntr,1);
pred_err            = Inf*ones(NoITCord+1,NoITC+1,Ntr,3,length(vec_N));
max_pred_err        = zeros(NoITCord+1,NoITC+1,Ntr,3,length(vec_N));
mat_phat            = Inf*ones(NoITCord+1,Ntr,length(vec_N));

for tr=1:Ntr

if mod(tr,1)==0,     
    %Generate coeff.
    if flag_gen_coeff == 0
        [Atrue, masktrue, spec_radtrue] = gen_coeff(K, p, c, z);
        ell = 1;
    else
        [Atrue, masktrue, spec_radtrue, ell] = gen_coeff_ell(K, p, c, z, lam_max );
    end
    vec_spec_rad_sys(tr) = spec_radtrue;
    masktrue1 = 1-masktrue;
else
    vec_spec_rad_sys(tr) =  vec_spec_rad_sys(tr-1);
end

%Generate data
all_data = arsim(zeros(K,1), cell2mat(Atrue), (ell^p*npow)*eye(K), Nmax+h);

for indN=1:length(vec_N)
N = vec_N(indN);   
fprintf('tr=%i N=%i\n', tr, N);
data = all_data(1:N,:);
% plot(data(:,1));

if flag_est_p==1,
    %Select the order of the model
    %ITC: (1) SBC; (2) FPE; (3) RNML; (4) AICC;
    [vec_phat, ~, Ah, Sh] = arfit_mod(data, pmin, pmax);
    ff = find(vec_phat==p);
    vec_phat = [vec_phat p];
    mat_phat(:,tr,indN) = vec_phat';
    if numel(ff)==0
        [~, ~, Atemp, Stemp] = arfit_mod(data, p, p);
        Ah{NoITCord+1} = Atemp{1};
        Sh{NoITCord+1} = Stemp{1};
    else
        Ah{NoITCord+1} = Ah{ff(1)};
        Sh{NoITCord+1} = Sh{ff(1)};
    end
    
else
    %Use the true order
    phat = size(Atrue,2);
    % phat = 1;
    vec_phat = phat;
    [~, ~, Ah, Sh] = arfit_mod(data, phat, phat);
end

for indp=1:length(vec_phat)
    phat = vec_phat(indp);
    ff = find(vec_phat(1:indp-1)==phat);
    if numel(ff)==0

        %Compute Wald statistics
        W = comp_W(data, Ah{indp}, Sh{indp});

        %Estimate masks 
        est_mask = comp_est_mask(p, W);

        %Use opt. algo. for estimation
        [val_crit, val_spec_rad, val_coeff, vec_diff] = opt_algo(data', phat, masktrue1, est_mask, nit, tol_pos, NoITC);

        for met=1:3
            for ind_crit=1:NoITC
            [~,w]                                     = min(val_crit(ind_crit,:,met));
            est_dist(indp,ind_crit,tr,met,indN)       = sum(sum(xor(masktrue1,est_mask{w})));
            est_spec_rad(indp,ind_crit,tr,met,indN)   = val_spec_rad(w,met);
            est_coeff{indp,ind_crit,tr,met,indN}      = val_coeff{w,met};
            end
        end
        
        
        %Oracle
        [est_dist, est_coeff, est_spec_rad] = oracle(data, phat, masktrue, vec_diff, NoITC, tr, indN, indp, nit, tol_pos, val_coeff, est_dist, est_coeff, est_spec_rad, val_spec_rad);

        %Prediction
        pred_data = all_data(N-phat+1:N+h,:);
        [pred_err, max_pred_err] = pred(pred_data, indN, tr, phat, indp, est_coeff, pred_err, max_pred_err, NoITC);
    
    else %numel(ff~=0)
         est_dist(indp,:,tr,:,indN)           = est_dist(ff(1),:,tr,:,indN);
         est_spec_rad(indp,:,tr,:,indN)       = est_spec_rad(ff(1),:,tr,:,indN);
         est_coeff(indp,:,tr,:,indN)          = est_coeff(ff(1),:,tr,:,indN); %modified August 21, 2018
         pred_err(indp,:,tr,:,indN)           = pred_err(ff(1),:,tr,:,indN);
         max_pred_err(indp,:,tr,:,indN)       = max_pred_err(ff(1),:,tr,:,indN);
         
    end %if numel
        
end %indp
    
end %sample size


save('all.mat');


end %trial

end %function

