function [Af, crit] = run_granger_stab(data, phat, maske_xor,  nit, tol_pos, Afsong)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Computes various results 
%Input:
% data          = measurements (K X N)
% phat          = est. order
% maske_xor     = xor mask
% nit           = no. of iterations
% tol_pos       = improves numerical conditioning
% Afsong        = coeff. estimated by Songsiri method
%Output:
% Af            = est. coeff. Af{1} ... Af{phat}
% val_crit      = values for four ITC
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

K = size(data,1);

% take a stable polynomial around which stability domain is built
% (note that the first coefficient is I, but it still should be given)
As{1} = eye(K);
if comp_spec_rad(Afsong)<1
    for j = 2 : phat+1
        As{j} = Afsong{j-1}; % Songsiri's model (guaranteed to be stable)
    end
else
    for j = 2 : phat+1
        As{j} = zeros(K);   % just zero because we don't know better
    end
end

% Iterative identification process with positive realness stability
% condition; in each iteration, the previous solution is the "center" of the
% stability domain
 
crit_old = Inf;
for i = 1 : nit
    [Af, crit] = granger_stab(data, phat, maske_xor, As, tol_pos);
    % fprintf('Posreal, it. %d: objective value = %4g\n', i, crit)
    % norm(Af{1}-Atrue{1})
    
    if crit==Inf
        for k = 2 : phat+1         
            Af{k-1} = As{k}; %previous solution
        end
        break;
    end
        
    
    if comp_spec_rad(Af)>=1
        for k = 2 : phat+1         
            Af{k-1} = As{k}; %previous solution
        end
        break;
    end
    
    if abs(crit-crit_old)<0.1
        break;
    else
        for k = 1 : phat         % change center of stability domain to current solution
            As{k+1} = Af{k};
        end
        crit_old = crit;
    end
end

end %function

